@@ -83,9 +83,17 @@
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
-;;; Completion function: C-i
+;;; Completion function for a draft only
 ;;;
 
+(defun mew-draft-set-completion-ignore-case (case)
+  ;; Need to set the global variable "completion-ignore-case",
+  ;; since clicking a candidate on a completion buffer checks
+  ;; the global variable.
+  ;; Yes, this has side-effect.
+  (when (mew-draft-or-header-p)
+    (setq completion-ignore-case case)))
+
 (defun mew-draft-header-comp ()
   "Complete and expand address short names.
 First, a short name is completed. When completed solely or the @ character
@@ -110,13 +118,45 @@ is inserted before the cursor, the short name is expanded to its address."
        "field"
        nil))))
 
+(defun mew-complete-newsgroups ()
+  (interactive)
+  (let ((word (mew-delete-backward-char)))
+    (if (null word)
+	(tab-to-tab-stop)
+      (mew-complete
+       word
+       (mew-nntp-folder-alist2 (mew-tinfo-get-case))
+       "newsgroup"
+       nil))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Completion function for both a draft and the minibuffer
+;;;
+
+(defun mew-complete-address ()
+  "Complete and expand an address short name.
+First alias key is completed. When completed solely or the @ character
+is inserted before the cursor, the short name is expanded to its address."
+  (interactive)
+  (mew-draft-set-completion-ignore-case mew-complete-address-ignore-case)
+  (let ((word (mew-delete-backward-char))
+    	(completion-ignore-case mew-complete-address-ignore-case))
+    (if (null word)
+	(tab-to-tab-stop)
+      (if (string-match "@." word)
+	  (insert (or (mew-addrbook-alias-next word mew-addrbook-alist) word))
+	(mew-complete
+	 word mew-addrbook-alist "alias" ?@ nil nil
+	 'mew-addrbook-alias-get
+	 'mew-addrbook-alias-hit)))))
+
 (defun mew-complete-local-folder ()
   "Local folder complete function."
   (interactive)
   (if mew-input-folder-search-direction
       (mew-input-folder-search-complete)
-    (when (mew-draft-or-header-p)
-      (setq completion-ignore-case mew-complete-folder-ignore-case))
+    (mew-draft-set-completion-ignore-case mew-complete-folder-ignore-case)
     (let ((word (mew-delete-backward-char))
 	  (completion-ignore-case mew-complete-folder-ignore-case))
       (if (null word)
@@ -126,18 +166,10 @@ is inserted before the cursor, the short name is expanded to its address."
 	    (mew-complete word (mew-complete-directory-alist word) "directory" nil)
 	  (mew-complete word (mew-local-folder-alist) "folder" nil))))))
 
-(defun mew-complete-imap-folder ()
-  "IMAP folder complete function."
-  (interactive)
-  (if mew-input-folder-search-direction
-      (mew-input-folder-search-complete)
-    (when (mew-draft-or-header-p)
-      (setq completion-ignore-case mew-complete-folder-ignore-case))
-    (let ((word (mew-delete-backward-char))
-	  (completion-ignore-case mew-complete-folder-ignore-case))
-      (if (null word)
-	  (mew-complete-window-show (list "%"))
-	(mew-complete word (mew-imap-folder-alist mew-inherit-case) "mailbox" nil)))))
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Completion function for the minibuffer only
+;;;
 
 (defun mew-complete-folder ()
   "Folder complete function."
@@ -161,8 +193,6 @@ is inserted before the cursor, the short name is expanded to its address."
     (mew-highlight-folder-comp-search-window)))
 
 (defun mew-complete-folder2 ()
-  (when (mew-draft-or-header-p)
-    (setq completion-ignore-case mew-complete-folder-ignore-case))
   (let ((word (mew-delete-backward-char nil ", \t\n"))
 	(completion-ignore-case mew-complete-folder-ignore-case)
 	case fld case-fld)
@@ -194,16 +224,15 @@ is inserted before the cursor, the short name is expanded to its address."
 	    (mew-temp-minibuffer-message " [No matching folder]")
 	  (message "No matching folder")))))
      (t
-      (setq case (or mew-inherit-case (mew-sinfo-get-case)))
       (cond
        ((mew-folder-localp word)
 	(mew-complete word (mew-local-folder-alist) "folder" nil))
        ((mew-folder-popp word)
 	(mew-complete word (mew-pop-folder-alist) "folder" nil))
        ((mew-folder-nntpp word)
-	(mew-complete word (mew-nntp-folder-alist case) "newsgroup" nil))
+	(mew-complete word (mew-nntp-folder-alist nil) "newsgroup" nil))
        ((mew-folder-imapp word)
-	(mew-complete word (mew-imap-folder-alist case) "mailbox" nil))
+	(mew-complete word (mew-imap-folder-alist nil) "mailbox" nil))
        ((mew-folder-virtualp word)
 	(mew-complete
 	 word (mew-buffer-list "^\\*" t 'mew-virtual-mode) "folder" nil))
@@ -216,48 +245,26 @@ is inserted before the cursor, the short name is expanded to its address."
 	 "case"
 	 nil)))))))
 
-(defun mew-complete-address ()
-  "Complete and expand an address short name.
-First alias key is completed. When completed solely or the @ character
-is inserted before the cursor, the short name is expanded to its address."
+;; called by mew-input-refile-folders.
+;; case is specified by mew-inherit-case.
+(defun mew-complete-imap-folder ()
+  "IMAP folder complete function."
   (interactive)
-  (when (mew-draft-or-header-p)
-    (setq completion-ignore-case mew-complete-address-ignore-case))
-  (let ((word (mew-delete-backward-char))
-    	(completion-ignore-case mew-complete-address-ignore-case))
-    (if (null word)
-	(tab-to-tab-stop)
-      (if (string-match "@." word)
-	  (insert (or (mew-addrbook-alias-next word mew-addrbook-alist) word))
+  (if mew-input-folder-search-direction
+      (mew-input-folder-search-complete)
+    (let ((word (mew-delete-backward-char))
+	  (completion-ignore-case mew-complete-folder-ignore-case))
+      (if (null word)
+	  (mew-complete-window-show (list "%"))
 	(mew-complete
-	 word mew-addrbook-alist "alias" ?@ nil nil
-	 'mew-addrbook-alias-get
-	 'mew-addrbook-alias-hit)))))
-
-(defun mew-complete-newsgroups ()
-  (interactive)
-  (when (mew-draft-or-header-p)
-    (setq completion-ignore-case mew-complete-address-ignore-case))
-  (let ((word (mew-delete-backward-char))
-   	(completion-ignore-case mew-complete-address-ignore-case))
-    (if (null word)
-	(tab-to-tab-stop)
-      (mew-complete
-       word
-       (mew-nntp-folder-alist2 mew-case-output)
-       "newsgroup"
-       nil))))
-
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;
-;;; Case
-;;;
+	 word
+	 (mew-imap-folder-alist mew-inherit-case) ;; ie mew-sinfo-get-case
+	 "mailbox"
+	 nil)))))
 
 (defun mew-complete-case ()
   "Complete function for cases."
   (interactive)
-  (when (mew-draft-or-header-p)
-    (setq completion-ignore-case mew-complete-case-ignore-case))
   (let ((word (or (mew-delete-backward-char) ""))
     	(completion-ignore-case mew-complete-case-ignore-case))
     (mew-complete
@@ -266,41 +273,9 @@ is inserted before the cursor, the short name is expanded to its address."
      "case"
      nil)))
 
-(defun mew-circular-complete-case ()
-  (interactive)
-  (if mew-input-folder-search-direction
-      (mew-input-folder-self-insert)
-    (let (cases oldcase newcase insert-:)
-      (save-excursion
-	(if (search-backward "," nil t)
-	    (forward-char 1)
-	  (beginning-of-line))
-	(if (looking-at mew-regex-case2)
-	    (progn
-	      (setq oldcase (mew-match-string 1))
-	      (delete-region (match-beginning 1) (match-end 1)))
-	  (setq oldcase mew-case-default)
-	  (setq insert-: t))
-	(if (setq cases (member oldcase mew-config-cases))
-	    (if (> (length cases) 1)
-		(setq newcase (nth 1 cases))
-	      (setq newcase (car mew-config-cases)))
-	  (setq newcase mew-case-default))
-	(if (string= newcase mew-case-default)
-	    (unless insert-: (delete-char 1))
-	  (insert newcase)
-	  (if insert-: (insert ":"))))
-      (if (or (= (point) (mew-minibuf-point-min))
-	      (save-excursion
-		(forward-char -1)
-		(looking-at "[:,]")))
-	  (if (search-forward "," nil t)
-	      (forward-char -1)
-	    (goto-char (point-max)))))))
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
-;;; Circular completion: C-cC-i
+;;; Circular completion function for a draft only
 ;;;
 
 (defun mew-draft-circular-comp ()
@@ -318,8 +293,8 @@ mew-mail-domain-list is inserted. If exists, the next value of
 mew-mail-domain-list concerned with the string between @ and 
 the cursor is inserted."
   (interactive)
-  (when (mew-draft-or-header-p)
-    (setq completion-ignore-case mew-circular-complete-domain-ignore-case))
+  (mew-draft-set-completion-ignore-case
+   mew-circular-complete-domain-ignore-case)
   (let ((word (mew-delete-backward-char "@"))
 	(completion-ignore-case mew-circular-complete-domain-ignore-case))
     (cond
@@ -363,7 +338,50 @@ the cursor is inserted."
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
-;;; Expansion : M-C-i
+;;; Circular completion function for the minibuffer only
+;;;
+
+(defun mew-circular-complete-case ()
+  (interactive)
+  (cond
+   ((null mew-input-folder-circular-case)
+    ())
+   ((eq mew-input-complete-function 'mew-complete-local-folder)
+    ())
+   (mew-input-folder-search-direction
+    (mew-input-folder-self-insert))
+   (t
+    (let (cases oldcase newcase insert-:)
+      (save-excursion
+	(if (search-backward "," nil t)
+	    (forward-char 1)
+	  (beginning-of-line))
+	(if (looking-at mew-regex-case2)
+	    (progn
+	      (setq oldcase (mew-match-string 1))
+	      (delete-region (match-beginning 1) (match-end 1)))
+	  (setq oldcase mew-case-default)
+	  (setq insert-: t))
+	(if (setq cases (member oldcase mew-config-cases))
+	    (if (> (length cases) 1)
+		(setq newcase (nth 1 cases))
+	      (setq newcase (car mew-config-cases)))
+	  (setq newcase mew-case-default))
+	(if (string= newcase mew-case-default)
+	    (unless insert-: (delete-char 1))
+	  (insert newcase)
+	  (if insert-: (insert ":"))))
+      (if (or (= (point) (mew-minibuf-point-min))
+	      (save-excursion
+		(forward-char -1)
+		(looking-at "[:,]")))
+	  (if (search-forward "," nil t)
+	      (forward-char -1)
+	    (goto-char (point-max))))))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Expansion for a draft only
 ;;;
 
 (defun mew-draft-expand ()
