@@ -233,7 +233,7 @@
 (defsubst mew-regex-jmp-msg (msg)
   (concat  "^[ ]*" msg "[^0-9]"))
 
-(defconst mew-regex-case "^\\([-a-zA-Z0-9_][-a-zA-Z0-9_]+\\):")
+(defconst mew-regex-case "^\\([-a-zA-Z0-9_][-a-zA-Z0-9_]+\\):\\(.*\\)")
 (defconst mew-regex-case2 "\\([-a-zA-Z0-9_][-a-zA-Z0-9_]+\\):")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -268,6 +268,7 @@
 ;;;
 
 (defconst mew-inherit-case nil)
+(defconst mew-inherit-exec-case nil)
 (defconst mew-inherit-alt nil)
 (defconst mew-inherit-7bit nil)
 (defconst mew-inherit-offline nil)
