@@ -266,7 +266,11 @@ Moreover, '~/.mew-fib' supports aliases like;
     (mew-set-buffer-cs mew-cs-m17n)
     ;; copy config, first
     (mew-tinfo-set-case mew-case-output)
-    (if mew-use-other-frame-for-draft (mew-tinfo-set-other-frame t))
+    (when mew-use-other-frame-for-draft
+      (mew-tinfo-set-other-frame t)
+      ;; to ensure to cite a message from summary frame.
+      (if (get-buffer (mew-buffer-message))
+	  (kill-buffer (mew-buffer-message))))
     (rename-buffer draftname)))
 
 (defun mew-draft-to-attach (draft)
@@ -459,6 +463,8 @@ citation prefix and label.
   "This value is used by mew-gnus.el to specify a buffer from where
 you can cite.")
 
+(defvar mew-message-citation-frame-id nil)
+
 (defun mew-draft-cite (&optional arg force)
   "Copy and paste a part of message from Message mode with
 citation prefix and label.
@@ -473,17 +479,19 @@ citation prefix and label.
   (interactive "P")
   (if (and (not force) (or (mew-in-header-p) (mew-in-attach-p)))
       (message "Cannot cite a message here")
-    (let ((nonmewbuf mew-message-citation-buffer) ;; buffer local, so copy here
-	  (fld (mew-current-get-fld (mew-frame-id)))
-	  (msg (mew-current-get-msg (mew-frame-id)))
-	  cite beg end tbuf irt-msgid)
+    (let* ((nonmewbuf mew-message-citation-buffer) ;; may be buffer local
+	   (fid (or mew-message-citation-frame-id (mew-frame-id))) 
+	   (fld (mew-current-get-fld fid))
+	   (msg (mew-current-get-msg fid))
+	   (msg-buf (mew-buffer-message))
+	   cite beg end tbuf irt-msgid)
+      (unless (get-buffer msg-buf)
+	(setq msg-buf mew-message-last-buffer))
       (save-excursion
 	;;
 	;; extract the body without header
 	;;
-	(setq tbuf (or nonmewbuf (mew-buffer-message)))
-	(if (and (not (get-buffer tbuf)) (get-buffer mew-message-last-buffer))
-	    (setq tbuf mew-message-last-buffer))
+	(setq tbuf (or nonmewbuf msg-buf))
 	(if (get-buffer tbuf)
 	    (set-buffer tbuf)
 	  (error "No buffer to be cited"))
@@ -508,12 +516,8 @@ citation prefix and label.
 	;; see also mew-summary-reply
 	(setq tbuf (or nonmewbuf
 		       (save-excursion
-			 (cond
-			  ((get-buffer (mew-buffer-message))
-			   (set-buffer (mew-buffer-message)))
-			  ((get-buffer mew-message-last-buffer)
-			   (set-buffer mew-message-last-buffer)))
-			 (if (mew-header-p) (current-buffer)))
+			 (when (get-buffer msg-buf)
+			   (if (mew-header-p) (current-buffer))))
 		       ;; header exists only in cache if multipart
 		       (mew-cache-hit fld msg)))
 	(if (get-buffer tbuf)
@@ -770,7 +774,7 @@ Set privacy service which will be effective when \\[mew-draft-make-message]."
   (let* ((services (mew-pcdb-services))
 	 (alist (mapcar (lambda (x) (cons (symbol-name x) x)) services))
 	 str)
-    (setq str (completing-read "Input privacy services : " alist nil t))
+    (setq str (completing-read "Input privacy services: " alist nil t))
     (when (stringp str)
       (mew-tinfo-set-privacy-type (cdr (assoc str alist)))
       (mew-tinfo-set-privacy-err nil)))
