@@ -103,7 +103,7 @@ This is O(N^2). So, do not use this function with a large LST."
 
 (defun mew-uniq-alist (alst)
   "Destructively uniqfy elements of ALST."
-  (let ((vec (make-vector 511 0))
+  (let ((vec (make-vector 511 0)) ;; hash
 	ent str ret)
     (while alst
       (setq ent (car alst))
@@ -159,21 +159,6 @@ This is O(N^2). So, do not use this function with a large LST."
 	    (throw 'loop a))
 	(setq alist (cdr alist))))))
 
-(defun mew-assoc-folder (key alist localp)
-  (let ((skey (downcase key))
-	(regex (concat mew-path-separator "$"))
-	a n ret)
-    (catch 'loop
-      (while alist
-	(setq a (car alist))
-	(setq n (nth 1 a))
-	(when (and (stringp n) (string= (downcase n) skey))
-	  (setq ret a)
-	  (unless (and localp (string-match regex (car a)))
-	    (throw 'loop nil)))
-	(setq alist (cdr alist))))
-    ret))
-
 (defun mew-assoc-match (key alist nth)
   "Return list in ALIST that KEY regex is matched to its NTH element.
 Case is ignored. Note that the NTH element is 't', 
@@ -469,7 +454,7 @@ also ignored."
 (defun mew-folder-case (folder)
   ;; "case" must be distinguished from drive
   (if (string-match mew-regex-case folder)
-      (cons (match-string 1 folder) (substring folder (match-end 0)))))
+      (cons (mew-match-string 1 folder) (mew-match-string 2 folder))))
 
 (defun mew-folder-folder (folder)
   (let ((case-folder (mew-folder-case folder)))
@@ -478,7 +463,9 @@ also ignored."
       folder)))
 
 (defun mew-folder-case-folder (case folder)
-  (if (and case (not (string= case mew-case-default)))
+  (if (and case
+	   (not (string= case mew-case-default))
+	   (mew-folder-remotep folder))
       (concat case ":" folder)
     folder))
 
@@ -576,12 +563,11 @@ also ignored."
 	(mew-string-to-local (substring path (match-end 0)))
       path)))
 
-(defun mew-canonicalize-case-folder (folder)
-  (let ((case-folder (mew-folder-case folder))
-	case)
-    (when case-folder
-      (setq case (car case-folder))
-      (setq folder (cdr case-folder)))
+(defun mew-canonicalize-case-folder (case:folder)
+  (let* ((case-folder (mew-folder-case case:folder))
+	 (case (car case-folder))
+	 (folder (cdr case-folder)))
+    (unless folder (setq folder case:folder))
     (cond
      ((mew-folder-localp folder) folder)
      ((mew-folder-absolutep folder) folder)
@@ -589,12 +575,8 @@ also ignored."
      (case
       (if (string-equal case mew-case-default)
 	  folder
-	(mew-folder-case-folder case folder)))
-     (t
-      (if (or (null mew-case-input)
-	      (string-equal mew-case-input mew-case-default))
-	  folder
-	(mew-folder-case-folder mew-case-input folder))))))
+	case:folder))
+     (t case:folder))))
 
 (defun mew-folder-remote-to-local (folder)
   (let ((case-folder (mew-folder-case folder))
@@ -708,9 +690,9 @@ also ignored."
 	(setq maxfile (int-to-string max))
 	(setq maxpath (mew-expand-folder folder maxfile)))
       (while (file-exists-p maxpath)
-	(setq maxfile (read-string (format "%s/%s exists. Input a message number : " max folder)))
+	(setq maxfile (read-string (format "%s/%s exists. Input a message number: " max folder)))
 	(while (not (string-match mew-regex-message-files maxfile))
-	  (setq maxfile (read-string "Input NUMBER : ")))
+	  (setq maxfile (read-string "Input NUMBER: ")))
 	(setq maxpath (mew-expand-folder folder maxfile)))
       (if num-only
 	  maxfile
@@ -895,7 +877,7 @@ Does not examine containing directories for links."
 	       (not (file-exists-p (expand-file-name fname mew-temp-dir))))
 	  (expand-file-name fname mew-temp-dir)	
 	(if (string-match "\\.[ -~]+$" fname)
-	    (concat (make-temp-name mew-temp-file) (match-string 0 fname))
+	    (concat (make-temp-name mew-temp-file) (mew-match-string 0 fname))
 	  (make-temp-name mew-temp-file)))
     (make-temp-name mew-temp-file)))
 
@@ -995,14 +977,6 @@ Does not examine containing directories for links."
 	    lines)
 	(- (buffer-size) (forward-line (buffer-size)))))))
 
-(defalias 'mew-buffer-substring 'buffer-substring-no-properties)
-(if (fboundp 'match-string-no-properties)
-    (defalias 'mew-match-string 'match-string-no-properties)
-  (defalias 'mew-match-string 'match-string))
-
-(defsubst mew-insert-buffer-substring (buf beg end)
-  (insert (save-excursion (set-buffer buf) (mew-buffer-substring beg end))))
-
 (defun mew-buffer-list (regex &optional listp mode)
   (let ((bufs (mapcar 'buffer-name (buffer-list)))
 	buf ret)
@@ -1075,7 +1049,7 @@ Does not examine containing directories for links."
     (if (or (not (intern-soft name))
 	    (not (boundp (intern name))))
 	(if (string-match "^mew-[^-]+-info-" name)
-	    (let* ((sym (intern (concat (match-string 0 name) "list")))
+	    (let* ((sym (intern (concat (mew-match-string 0 name) "list")))
 		   (lst (symbol-value sym))
 		   (len (length lst)))
 	      (set (intern name) (make-vector len nil)))))
@@ -1308,6 +1282,9 @@ by side-effect."
   (let ((system-time-locale "C"))
     (format-time-string "%Y%m%d%H%M%S" time)))
 
+(defsubst mew-time-ctz-to-sortkey-invalid (sec min hour day mon year)
+  (format "%04d%02d%02d%02d%02d%02d" year mon day hour min sec))
+
 ;; "20000726121835"
 (defsubst mew-time-rfc-to-sortkey (s)
   (if (string-match mew-time-rfc-regex s)
@@ -1322,11 +1299,12 @@ by side-effect."
 	 ((< year 50)
 	  (setq year (+ year 2000)))
 	 ((< year 100)
-	  (setq year (+ year 1900)))
-	 ((or (< year 1970) (>= year 2038)) ;; error data
-	  (setq year 2037)))
-	(setq sec (- sec tmzn))
-	(mew-time-ctz-to-sortkey (encode-time sec min hour day mon year)))))
+	  (setq year (+ year 1900))))
+	(if (or (< year 1970) (>= year 2038))
+	    ;; invalid data
+	    (mew-time-ctz-to-sortkey-invalid sec min hour day mon year)
+	  (setq sec (- sec tmzn))
+	  (mew-time-ctz-to-sortkey (encode-time sec min hour day mon year))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
