@@ -351,7 +351,7 @@ original position."
       (setq ent (car alist))
       (setq alist (cdr alist))
       (setq fld (car ent))
-      (setq msgs (sort (cdr ent) '<))
+      (setq msgs (sort (copy-sequence (cdr ent)) '<)) ;; sort has side effect
       (when (get-buffer fld)
 	(set-buffer fld)
 	(save-excursion
@@ -370,7 +370,7 @@ original position."
       (setq ent (car alist))
       (setq alist (cdr alist))
       (setq fld (car ent))
-      (setq msgs (sort (cdr ent) '<))
+      (setq msgs (sort (copy-sequence (cdr ent)) '<)) ;; sort has side effect
       (when (get-buffer fld)
 	(set-buffer fld)
 	(save-excursion
@@ -440,7 +440,8 @@ for '\\[mew-summary-multi-forward]', '\\[mew-summary-unshar]', '\\[mew-summary-u
 (defun mew-summary-unlink (&optional count)
   "Put the unlink mark (default is 'X') in COUNT times."
   (interactive "P")
-  (mew-mark-put-mark-loop 'mew-summary-unlink-one count nil))
+  (mew-summary-not-in-nntp
+   (mew-mark-put-mark-loop 'mew-summary-unlink-one count nil)))
 
 (defun mew-summary-unlink-one (&optional no-msg)
   "Put the unlink mark (default is 'X') on this message."
@@ -608,7 +609,7 @@ region."
 	    (setq size 7211))
 	   (t
 	    (setq size 18211)))
-	  (setq ids (make-vector size 0))
+	  (setq ids (make-vector size 0)) ;; hash
 	  (save-restriction
 	    (narrow-to-region beg end)
 	    (goto-char (if reversep (point-max) (point-min)))
