@@ -77,7 +77,7 @@
     (mew-nntp-process-send-string pro "AUTHINFO PASS %s" pass)))
 
 (defun mew-nntp-command-wpwd (pro pnm)
-  (mew-nntp-message "AUTHINFO password is wrong!")
+  (mew-nntp-message pnm "AUTHINFO password is wrong!")
   (mew-passwd-set-passwd (mew-nntp-passtag pnm) nil)
   (mew-nntp-set-status pnm "pre-quit"))
 
@@ -253,7 +253,7 @@
 
 (defun mew-nntp-command-post-list (pro pnm)
   (let ((case (mew-nntp-get-case pnm))
-	group groups groups2)
+	group group2 groups groups2)
     (goto-char (point-min))
     (forward-line)
     (delete-region (point-min) (point))
@@ -262,9 +262,10 @@
     (mew-dot-delete)
     (while (not (eobp))
       (when (looking-at "\\([a-z][^ \t]+\\)")
-	(setq group (mew-match-string 1))
-	(setq groups (cons (list (concat mew-folder-nntp group)) groups))
-	(setq groups2 (cons (list group) groups2)))
+	(setq group2 (mew-match-string 1))
+	(setq group (concat mew-folder-nntp group2)) 
+	(setq groups (cons (mew-folder-func group) groups))
+	(setq groups2 (cons (mew-folder-func group2) groups2)))
       (forward-line))
     (if (null case) (setq case mew-case-default))
     (setq groups (nreverse groups))
@@ -589,7 +590,7 @@
   (let ((bnm (mew-summary-folder-name 'ext))
 	(case (mew-sinfo-get-case)))
     (if mew-config-cases
-	(setq case (mew-input-case case "NNTP"))) ;; xxx mew-case-input
+	(setq case (mew-input-case case "NNTP")))
     (mew-nntp-retrieve case 'list bnm)))
 
 (provide 'mew-nntp)
