@@ -246,6 +246,7 @@ threads are created, see 'mew-use-complete-thread'."
 	    (vfolder (mew-folder-to-thread folder))
 	    (disp (mew-sinfo-get-disp-msg))
 	    (ctime (mew-sinfo-get-cache-time))
+	    (case (mew-sinfo-get-case))
 	    (column (mew-summary-scan-form folder 'column))
 	    (numlen (mew-summary-scan-form-num folder))
  	    overnum spacer indentlst
@@ -264,7 +265,7 @@ threads are created, see 'mew-use-complete-thread'."
 	   (setq size 7211))
 	  (t
 	   (setq size 18211)))
-	 (setq db (make-vector size 0))
+	 (setq db (make-vector size 0)) ;; hash
 	 (save-excursion
 	   ;; Calculate message number width
  	   (goto-char (point-max))
@@ -328,6 +329,7 @@ threads are created, see 'mew-use-complete-thread'."
 	 (mew-hscroll)
 	 (mew-summary-toggle-disp-msg (if disp 'on 'off))
 	 (mew-sinfo-set-cache-time ctime)
+	 (mew-sinfo-set-case case)
 	 (setq mew-summary-buffer-raw t)
 	 (mew-vinfo-set-top nil)
 	 (mew-vinfo-set-db db)
@@ -556,7 +558,7 @@ with the current folder as a candidate in addition to guessed folders."
       (setq ent (car alist))
       (setq alist (cdr alist))
       (setq fld (car ent))
-      (setq msgs (sort (cdr ent) '<))
+      (setq msgs (sort (copy-sequence (cdr ent)) '<)) ;; sort has side effect
       (while msgs
 	(setq msg (int-to-string (car msgs)))
 	(setq msgs (cdr msgs))
@@ -653,7 +655,7 @@ with the current folder as a candidate in addition to guessed folders."
       (setq ent (car alist))
       (setq alist (cdr alist))
       (setq fld (car ent))
-      (setq msgs (sort (cdr ent) '<))
+      (setq msgs (sort (copy-sequence (cdr ent)) '<)) ;; sort has side effect
       (when (get-buffer fld)
 	(set-buffer fld)
 	(save-excursion
