@@ -108,7 +108,7 @@
   :type 'file)
 
 (defcustom mew-mail-path "~/Mail"
-  "*A directory where mail folders locate."
+  "*A directory where folders locate."
   :group 'mew-env
   :type 'directory)
 
@@ -140,7 +140,7 @@ really deleted."
   :type 'string)
 
 (defcustom mew-inbox-folder "+inbox"
-  "*The folder where new mails are incorporated."
+  "*The folder where new messages are incorporated."
   :group 'mew-folder
   :type 'string)
 
@@ -150,7 +150,7 @@ really deleted."
   :type 'string)
 
 (defcustom mew-trash-folder "+trash"
-  "*The folder where trashed mails are contained."
+  "*The folder where trashed messages are contained."
   :group 'mew-folder
   :type 'string)
 
@@ -532,15 +532,13 @@ of Message-ID:."
 ;;; mbox
 ;;;
 
-(defcustom mew-mbox-command nil
-  "*A command to be execute if 'mew-mailbox-type' is 'mbox. A good
-example is \"inc\"."
+(defcustom mew-mbox-command "incm"
+  "*A command to be execute if 'mew-mailbox-type' is 'mbox. "
   :group 'mew-pop
   :type '(choice string (const nil)))
 
 (defcustom mew-mbox-command-arg nil
-  "*Arguments for 'mew-mbox-command'.
-A good example is \"-truncate -file /var/mail/user\"."
+  "*Arguments for 'mew-mbox-command'."
   :group 'mew-pop
   :type '(choice string (const nil)))
 
@@ -1192,6 +1190,16 @@ to this file."
   :group 'mew-draft
   :type 'boolean)
 
+(defcustom mew-ask-to nil
+  "*If *non-nil*, ask a user to whom he/she sends."
+  :group 'mew-draft
+  :type 'boolean)
+
+(defcustom mew-ask-cc nil
+  "*If *non-nil*, ask a user to whom he/she sends Cc."
+  :group 'mew-draft
+  :type 'boolean)
+
 (defcustom mew-ask-fcc nil
   "*If *non-nil* and a folder on Fcc: does not exist, ask a user to
 create it. If nil, folders which are not present are created without
@@ -1315,14 +1323,14 @@ is used as a folder candidate instead of inbox."
   :type 'boolean)
 
 (defcustom mew-use-biff nil
-  "*If non-nil, Mew displays \"Mail(n)\" in the mode line if your mail
-server receives messages. This is confirmed by POP or IMAP every
-'mew-biff-interval' minutes.
+  "*If non-nil, Mew displays \"Mail(n)\" in the mode line if your
+message server receives messages. This is confirmed by POP or IMAP
+every 'mew-biff-interval' minutes.
 
 To use this feature, 'mew-use-cached-passwd' should be 't'.
 
-If you want to use the biff functionality against a local spool, use
-'display-time-mode instead. "
+If you want to use the biff functionality against a local mailbox, use
+'display-time-mode' instead. "
   :group 'mew-env
   :type 'boolean)
 
@@ -1369,6 +1377,24 @@ multipart is displayed with its header."
   :group 'mew-net
   :type 'boolean)
 
+(defcustom mew-use-fast-refile nil
+  "*If non-nil, 'rassoc' is used to look up the alist of
+folders. Since it is a built-in function, it makes marking for refile
+much faster especially when the alist is long. But the fast method
+is not case-sensitive. So, you should set this variable to 't' only when
+you does not use capital letters for your folders. If nil, the old
+slow method, which is case-sensitive, is used."
+  :group 'mew-refile
+  :type 'boolean)
+
+(defcustom mew-use-case-input-completion t
+  "*If non-nil, 'mew-case-input' is automatically completed when you
+input a folder.  For example, consider that you input a folder in a
+local folder after typing '\\<mew-summary-mode-map>\\[mew-summary-goto-folder]'.  
+Typing '%' automatically inserts 'mew-case-input' before '%'."
+  :group 'mew-summary
+  :type 'boolean)
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Appearance
@@ -2051,8 +2077,8 @@ confirmation before refiling."
   :type 'boolean)
 
 (defcustom mew-refile-guess-from-me-is-special nil
-  "*If *non-nil*, 'mew-refile-guess-by-from-*' think the mails from yourself
-as special. They use To: or Cc: instead of From:"
+  "*If *non-nil*, 'mew-refile-guess-by-from-*' think the messages from
+yourself as special. They use To: or Cc: instead of From:"
   :group 'mew-refile
   :type 'boolean)
 
@@ -2095,6 +2121,13 @@ Otherwise, the old cases are overridden."
   :group 'mew-draft
   :type 'boolean)
 
+(defcustom mew-case-synchronize t
+  "'\\<mew-summary-mode-map>If non-nil, \\[mew-summary-set-case] sets both
+'mew-case-input' and 'mew-case-output'. If nil, \\[mew-summary-set-case] sets 'mew-case-input' only. 
+Use \\[universal-argument]\\[mew-summary-set-case] to set 'mew-case-output'."
+  :group 'mew-summary
+  :type 'boolean)
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Delete
@@ -2333,11 +2366,6 @@ will be automatically leaned as alias."
   :group 'mew-addrbook
   :type 'boolean)
 
-(defcustom mew-alias-comment-regex "^;.*$\\|#.*$"
-  "*Regular expression for the old Aliases."
-  :group 'mew-addrbook
-  :type 'regexp)
-
 (defcustom mew-addrbook-comment-regex "^;.*$\\|#.*$"
   "*Regular expression for Addrbook."
   :group 'mew-addrbook
