@@ -860,20 +860,20 @@ following in .emacs.
 (defvar mew-proto mew-folder-local)
 
 (defvar mew-proto-spec
-  ;; key go refile inc flush
-  '(("+" "+" "+" "+" "+")
-    ("$" "+" nil "$" "+")
-    ("%" "%" "%" "%" "+")
-    ("*" nil nil nil nil)
-    ("-" "-" nil nil "-")))
+  ;; key go refile flush
+  '(("+" "+" "+" "+")
+    ("$" "+" nil "+")
+    ("%" "%" "%" "+")
+    ("*" nil nil nil)
+    ("-" "-" nil "-")))
 
 (defun mew-proto-to-body (fld n)
-  (setq fld (mew-folder-folder fld))
   (if (mew-folder-virtualp fld)
       (setq fld (mew-thread-to-folder fld)))
+  (setq fld (mew-folder-folder fld))
   (let ((proto (mew-folder-prefix fld)))
     (unless (member proto mew-folder-prefixes)
-      (setq proto (mew-proto mew-case-input)))
+      (setq proto (mew-proto))) ;; default proto
     (nth n (assoc proto mew-proto-spec))))
 
 (defun mew-proto-to-go (fld)
@@ -882,11 +882,8 @@ following in .emacs.
 (defun mew-proto-to-refile (fld)
   (mew-proto-to-body fld 2))
 
-(defun mew-proto-to-inc (fld)
-  (mew-proto-to-body fld 3))
-
 (defun mew-proto-to-flush (fld)
-  (mew-proto-to-body fld 4))
+  (mew-proto-to-body fld 3))
 
 (defun mew-proto-inbox-folder (proto &optional case)
   (or proto (setq proto (mew-proto case)))
