@@ -63,27 +63,32 @@ execute 'mew-summary-virtual-with-external'. Otherwise,
 	  (message "mew-summary-virtual-with-external-function is nil"))
       (mew-summary-virtual-with-internal))))
 
-(defun mew-summary-virtual-with-internal ()
-  "Create Virtual mode with mewls."
-  (let* ((flds (mew-input-folders (list (mew-summary-folder-name))))
-	 (folders (mapcar 'mew-folder-remote-to-local flds))
-	 (vfolder (mew-folder-to-virtual (mapconcat 'identity flds ",")))
-	 (pattern (mew-input-pick-pattern))
-	 opts lra)
-    (if mew-ask-virtual-folder-name
-	(setq vfolder
-	      (mew-input-string "Virtual folder name %s(%s): " "" vfolder)))
+(defun mew-summary-get-vfolder (flds)
+  (let ((vfolder (mew-folder-to-virtual (mapconcat 'identity flds ","))))
+    (when mew-ask-virtual-folder-name
+      (setq vfolder (mew-input-string
+		     "Virtual folder name %s(%s): " "" vfolder)))
     (unless (mew-folder-virtualp vfolder)
       (setq vfolder (mew-folder-to-virtual vfolder)))
-    (mew-summary-switch-to-folder vfolder)
-    (when (mew-summary-exclusive-p)
-      (while folders
-	(setq opts (cons (car folders) (cons "-s" opts)))
-	(setq lra (cons (cons (car folders) (car flds)) lra))
-	(setq flds (cdr flds))
-	(setq folders (cdr folders)))
-      (setq opts (cons "-a" (cons "-p" (cons pattern (nreverse opts)))))
-      (mew-local-retrieve 'vir opts 1 nil lra))))
+    vfolder))
+
+(defun mew-summary-virtual-with-internal ()
+  "Create Virtual mode with mewls."
+  (let* ((flds (mew-input-folders (mew-summary-folder-name)))
+	 folders vfolder pattern opts lra)
+    (when flds
+      (setq folders (mapcar 'mew-folder-remote-to-local flds))
+      (setq pattern (mew-input-pick-pattern))
+      (setq vfolder (mew-summary-get-vfolder flds))
+      (mew-summary-switch-to-folder vfolder)
+      (when (mew-summary-exclusive-p)
+	(while folders
+	  (setq opts (cons (car folders) (cons "-s" opts)))
+	  (setq lra (cons (cons (car folders) (car flds)) lra))
+	  (setq flds (cdr flds))
+	  (setq folders (cdr folders)))
+	(setq opts (cons "-a" (cons "-p" (cons pattern (nreverse opts)))))
+	(mew-local-retrieve 'vir opts 1 nil lra)))))
 
 (defvar mew-summary-virtual-with-external-function
   'mew-summary-virtual-with-grep
@@ -93,35 +98,31 @@ This function MUST returns a file name which contains message numbers.")
 (defun mew-summary-virtual-with-external ()
   "Create Virtual mode with 'mew-summary-virtual-with-external-function'."
   (interactive)
-  (let* ((flds (mew-input-folders (list (mew-summary-folder-name))))
-	 (folders (mapcar 'mew-folder-remote-to-local flds))
-	 (vfolder (mew-folder-to-virtual (mapconcat 'identity flds ",")))
-	 (pattern (mew-input-grep-pattern))
+  (let* ((flds (mew-input-folders (mew-summary-folder-name)))
 	 (buf (generate-new-buffer mew-buffer-prefix))
-	 file func opts lra)
-    (if mew-ask-virtual-folder-name
-	(setq vfolder
-	      (mew-input-string "Virtual folder name %s(%s): " "" vfolder)))
-    (unless (mew-folder-virtualp vfolder)
-      (setq vfolder (mew-folder-to-virtual vfolder)))
-    (mew-summary-switch-to-folder vfolder)
-    (when (mew-summary-exclusive-p)
-      (save-excursion
-	(set-buffer buf)
-	(mew-erase-buffer)
-	(mew-piolet
-	 mew-cs-text-for-read mew-cs-text-for-write
-	 (mew-alet
-	  (setq file (funcall mew-summary-virtual-with-external-function
-			      folders pattern)))))
-      (mew-remove-buffer buf)
-      (setq func `(lambda () (mew-delete-file ,file)))
-      (setq opts (list "-i" file))
-      (while folders
-	(setq lra (cons (cons (car folders) (car flds)) lra))
-	(setq flds (cdr flds))
-	(setq folders (cdr folders)))
-      (mew-local-retrieve 'vir opts 1 func lra))))
+	 folders vfolder pattern file func opts lra)
+    (when flds
+      (setq folders (mapcar 'mew-folder-remote-to-local flds))
+      (setq pattern (mew-input-grep-pattern))
+      (setq vfolder (mew-summary-get-vfolder flds))
+      (mew-summary-switch-to-folder vfolder)
+      (when (mew-summary-exclusive-p)
+	(save-excursion
+	  (set-buffer buf)
+	  (mew-erase-buffer)
+	  (mew-piolet
+	   mew-cs-text-for-read mew-cs-text-for-write
+	   (mew-alet
+	    (setq file (funcall mew-summary-virtual-with-external-function
+				folders pattern)))))
+	(mew-remove-buffer buf)
+	(setq func `(lambda () (mew-delete-file ,file)))
+	(setq opts (list "-i" file))
+	(while folders
+	  (setq lra (cons (cons (car folders) (car flds)) lra))
+	  (setq flds (cdr flds))
+	  (setq folders (cdr folders)))
+	(mew-local-retrieve 'vir opts 1 func lra)))))
 
 (defun mew-summary-virtual-with-grep (flds pattern)
   (setq pattern (mew-cs-encode-arg pattern))
