@@ -2,7 +2,7 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Mar 23, 1994
-;; Revised: Oct 29, 2002
+;; Revised: Dec  2, 2002
 
 ;;; Commentary:
 
@@ -19,7 +19,7 @@
 ;;; Mew version
 ;;;
 
-(defconst mew-version-number "3.0.72"
+(defconst mew-version-number "3.1"
   "Version number for this version of Mew.")
 (defconst mew-version (format "Mew version %s" mew-version-number)
   "Version string for this version of Mew.")
@@ -32,6 +32,8 @@
 (cond
  ((eq system-type 'windows-nt)
   (require 'mew-win32))
+ ((eq system-type 'darwin)
+  (require 'mew-darwin))
  (t
   (require 'mew-unix)))
 
@@ -67,20 +69,36 @@
 
 ;;;###autoload
 (defun mew (&optional arg)
-  "Execute Mew. If 'mew-auto-get' is 't', messages stored in your
-mailbox are fetched to the +inbox (or %inbox) folder and are listed up
-in Summary mode. If 'mew-auto-get' is 'nil', list up messages in the
-inbox folder. If '\\[universal-argument]' is specified, perform this
-function thinking that 'mew-auto-get' is reversed."
+  "Execute Mew first unless Mew is running. And retrieve arrived
+messages or just visit to the default folder.
+
+'proto' is determined by 'mew-proto' and 'mew-input-case'.  
+
+If 'proto' is '+' (ie a local folder), a mailbox is determined
+according to 'mew-mailbox-type'. Otherwise (ie a remote folder), an
+appropriate protocol to retrieve messages is chosen according to
+'proto'.
+
+If 'mew-auto-get' is 't', arrived messages are asynchronously fetched
+and listed up in Summary mode.
+
+'mew-auto-get' is 'nil', just visit to the folder determined by
+'proto'.
+
+When executed with '\\[universal-argument]', 'mew-auto-get' is
+considered reversed."
   (interactive "P")
   (mew-window-push)
   (unless mew-init-p (mew-init))
-  (let ((auto (if arg (not mew-auto-get) mew-auto-get))
-	inbox)
+  (let* ((auto (if arg (not mew-auto-get) mew-auto-get))
+	 (case mew-case-input)
+	 (proto (mew-proto case))
+	 inbox)
     (if auto
-	(mew-summary-retrieve)
+	(mew-summary-scan-boot proto case)
       ;; see also mew-summary-retrieve
-      (setq inbox (mew-proto-inbox-folder nil mew-case-input))
+      (setq inbox (mew-proto-inbox-folder proto case))
+      (setq inbox (mew-folder-case-folder case inbox))
       (mew-summary-visit-folder inbox 'goend 'no-ls))
     (setq mew-inbox-window (current-window-configuration))))
 
@@ -97,7 +115,7 @@ function."
 (defun mew-user-agent-compose (&optional to subject other-headers continue
                                              switch-function yank-action
                                              send-actions)
-  "Set up mail composition draft with Mew.
+  "Set up message composition draft with Mew.
 This is 'mail-user-agent' entry point to Mew.
 
 The optional arguments TO and SUBJECT specify recipients and the
